
#line 3 "lev_lex.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex via 'flex -S flexhack.skl'
 * where flexhack.skl is a nethack-specific alternate skeleton derived
 * from flex 2.6.0's skel.c (which in turn was generated from flex.skl).
 *
 * Support for C++, re-entrancy, and table serialization stripped out.
 * NetHack's usage doesn't need them and we want to reduce the size and
 * complexity of this skeleton as well as of the generated scanner code.
 */
#define FLEXHACK_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 0

#include "config.h"

#include <errno.h>

/* we don't care if actual types happen to have more bits than their names;
   the tables will just take up more space, possibly slowing the parse;
   still, allow config.h to override these via typedef+#define if desired */
#ifndef FLEX_INT32_T
typedef int flex_int32_t;
#endif
#ifndef FLEX_INT16_T
typedef short int flex_int16_t;
#endif
#ifndef FLEX_UINT16_T
typedef unsigned short int flex_uint16_t;
#endif

#define yyconst const

#define FDECL_dummy /*empty*/

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (uchar) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character
 * in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern yy_size_t yyleng;
extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

#define YY_LESS_LINENO(n)
#define YY_LINENO_REWIND_TO(ptr)

/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
    do { \
        /* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg); \
        *yy_cp = (yy_hold_char); \
        YY_RESTORE_YY_MORE_OFFSET \
        (yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
        YY_DO_BEFORE_ACTION; /* set up yytext again */ \
    } while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state {
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	yy_size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

        int yy_bs_lineno; /**< The line count. */
        int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static yy_size_t yy_n_chars;	/* number of characters read into yy_ch_buf */
yy_size_t yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart FDECL(FDECL_dummy, (FILE *input_file  ));
void yy_switch_to_buffer FDECL(FDECL_dummy, (YY_BUFFER_STATE new_buffer  ));
YY_BUFFER_STATE yy_create_buffer FDECL(FDECL_dummy, (FILE *file,int size  ));
void yy_delete_buffer FDECL(FDECL_dummy, (YY_BUFFER_STATE b  ));
void yy_flush_buffer FDECL(FDECL_dummy, (YY_BUFFER_STATE b  ));
void yypush_buffer_state FDECL(FDECL_dummy, (YY_BUFFER_STATE new_buffer  ));
void yypop_buffer_state FDECL(FDECL_dummy, (void ));

static void yyensure_buffer_stack FDECL(FDECL_dummy, (void ));
static void yy_load_buffer_state FDECL(FDECL_dummy, (void ));
static void yy_init_buffer FDECL(FDECL_dummy, (YY_BUFFER_STATE b,FILE *file  ));

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer FDECL(FDECL_dummy, (char *base,yy_size_t size  ));
YY_BUFFER_STATE yy_scan_string FDECL(FDECL_dummy, (yyconst char *yy_str  ));
YY_BUFFER_STATE yy_scan_bytes FDECL(FDECL_dummy, (yyconst char *bytes,yy_size_t len  ));

void *yyalloc FDECL(FDECL_dummy, (yy_size_t  ));
void *yyrealloc FDECL(FDECL_dummy, (void *,yy_size_t  ));
void yyfree FDECL(FDECL_dummy, (void *  ));

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	    if ( ! YY_CURRENT_BUFFER ) { \
	        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE = \
			yy_create_buffer(yyin,YY_BUF_SIZE ); \
	    } \
	    YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	    if ( ! YY_CURRENT_BUFFER ) { \
		yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE = \
			yy_create_buffer(yyin,YY_BUF_SIZE ); \
	    } \
	    YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *yyin = (FILE *) 0, *yyout = (FILE *) 0;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state FDECL(FDECL_dummy, (void ));
static yy_state_type yy_try_NUL_trans FDECL(FDECL_dummy, (yy_state_type current_state  ));
static int yy_get_next_buffer FDECL(FDECL_dummy, (void ));
static void yy_fatal_error FDECL(FDECL_dummy, (yyconst char msg[]  )) NORETURN;

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 200
#define YY_END_OF_BUFFER 201
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[1057] =
    {   0,
        0,    0,    0,    0,  201,  199,  195,  194,  199,  199,
      199,  199,  199,  199,  198,  184,  192,  199,  193,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  198,  198,
      198,  198,  198,  198,  198,  198,  198,  199,  198,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  198,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  198,  198,
      195,  199,  198,    2,  199,  195,  199,  199,  198,  184,
      198,  198,  198,  198,  198,  198,  198,  198,  198,  198,
      198,  198,  195,  199,  195,  194,  188,    0,  185,  186,
        0,    0,  182,  198,  181,  183,  184,  198,  190,  189,

      187,  191,  198,  198,  198,  198,  198,  198,  198,  198,
      198,  198,  198,  198,  198,  198,  198,  198,   39,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  198,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  198,  198,
       55,  198,  198,    0,    0,  198,  198,  198,  198,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  198,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  198,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  198,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  198,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  198,  198,

      198,  198,  198,  198,  198,  198,  198,  198,  198,  198,
      198,  198,  154,  198,  198,  195,    0,    0,    3,  198,
        2,    2,    0,  195,    0,  182,  198,  181,  184,  198,
      198,  198,  198,   39,  198,  198,  198,  198,  198,  198,
      195,    0,    2,    0,    0,  197,    0,  197,  179,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  198,  198,
      198,  198,   54,  198,  198,  198,  198,  198,  198,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  198,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  198,  198,
      198,  198,  198,  198,  198,    0,  198,  104,  198,   83,

      198,  198,  198,  198,  198,  198,  198,  198,  198,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  198,  198,
      198,   79,  198,  198,  198,  198,  198,  198,  198,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  198,   81,
      198,  198,  198,  198,  198,  139,  198,  198,  198,  198,
      128,  198,  198,  198,  198,  198,  198,  198,  198,  198,
      198,  198,  198,  198,  198,  198,  198,   16,  198,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  198,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  198,  198,
      198,  198,  126,  198,  198,  198,  198,  198,  198,  198,

      198,   80,  198,  198,  198,  198,  198,  198,  198,  198,
      196,  198,  198,  198,   58,  198,  198,  198,   22,  198,
       40,  198,   41,  198,  198,  198,  198,   49,  198,  198,
      198,  198,   56,    6,  198,  198,  198,   53,  198,  198,
      198,   36,  198,  198,  198,  198,   42,  198,   35,  198,
      198,  198,  198,  198,   21,  198,    0,  180,  198,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  198,  198,
      160,  198,  198,  198,  198,  198,  198,  198,  198,  198,
      198,  155,  158,  114,  198,  198,  198,  198,  198,  198,
      198,  198,  198,  198,  198,  198,   69,  198,  198,  198,

      198,  198,  198,  198,  198,  198,  121,  198,  198,   67,
      198,  198,  198,  198,  161,  198,  198,  198,  198,  198,
      198,  198,  198,  198,  119,  198,  198,  198,  198,  107,
      198,  198,  198,  198,  198,  198,  198,   65,  198,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  198,  198,
      198,  198,  198,  198,  198,  198,  157,  198,  198,  198,
      198,  198,  116,   15,    0,  198,  198,  198,  198,  198,
       28,  198,   59,  198,  198,  198,  198,  198,   13,  198,
      198,  198,   50,  198,  198,    7,  198,  198,  198,  198,
        5,  198,  198,  198,  198,  198,  198,  198,  198,  198,

       30,  198,  198,  198,  198,  198,  120,  153,  198,  198,
      198,  147,  198,  198,  162,  198,  198,  198,  198,  198,
      141,  198,  198,  198,  198,  198,  198,  198,  198,  198,
      198,  156,  198,  198,  198,  198,  198,  198,  198,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  198,  198,
      198,  198,  198,  198,  198,  198,  198,  198,   11,  198,
      198,  198,  198,  198,  198,  198,  113,  198,  198,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  198,  198,
      125,  198,   12,  198,  198,  198,  198,  198,  198,  198,
       82,  115,  198,  198,  198,  198,  198,  198,  198,  198,

      129,  198,  198,  198,  198,   33,  198,  198,  198,  198,
      198,  198,  198,  198,  198,   29,  198,  198,  198,  198,
      198,  198,   17,   31,  198,   27,  198,  198,  198,  198,
       57,  198,  198,  198,  198,  146,   97,  198,  198,  127,
      111,   86,  198,  123,   72,  108,  198,  198,  198,  198,
      165,  198,  198,   87,  198,   94,  130,  198,   74,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  198,  198,
      198,  198,  198,  135,  198,  198,  109,  198,  198,  198,
      198,  198,  198,  198,  198,  198,  110,  168,  198,  198,
      198,   16,  198,  198,  198,  198,   77,  198,  117,  198,

      198,  198,  198,  198,  112,  198,  198,  198,  152,  173,
      198,  198,   78,  198,  198,  198,  198,  198,  198,  198,
      198,    1,   57,  198,  198,  198,   60,  198,  198,  198,
      198,  198,  198,  198,    4,  198,   19,  198,  198,  198,
      198,  198,   62,   43,  198,   46,   26,  198,  163,   99,
      198,  198,  198,  198,  198,   73,  159,  198,  198,   98,
      198,  198,  198,   93,  198,  198,  198,  198,  145,  198,
      198,  198,  198,  198,  136,  198,  198,  198,  198,  198,
       20,   63,  140,  138,  198,  198,  198,  198,  198,  198,
      198,  198,  118,  198,  132,   96,  198,  151,  198,  198,

      198,  198,  198,  101,   47,   89,  198,  198,  198,  198,
      198,  198,   45,  198,  198,   34,   61,   14,    8,   25,
      198,  198,  198,  198,  198,   23,  198,  169,  198,  198,
      198,  102,  177,  198,   66,  198,   75,  198,  198,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  198,  150,
        9,  198,  198,  198,  198,  198,  144,  198,   85,   68,
      198,   71,  198,  198,  198,  198,  176,  164,  131,  134,
      198,  106,   18,  198,   51,  198,  198,  198,  198,  198,
      198,   95,  142,  198,  198,   70,  174,  122,  198,  167,
      198,  175,  198,   92,  133,   84,  148,  149,  171,  198,

      198,  198,  100,  172,   91,  198,   64,  198,   10,  137,
       24,   52,  198,  198,  198,  198,  198,   76,   88,  124,
      105,  198,  198,  198,  166,  103,  198,  198,  198,  198,
      198,  198,  198,  198,   90,  198,   37,   38,  198,  198,
      198,  198,  143,  170,  198,  198,  198,  178,  198,  198,
      198,  198,   48,   32,   44,    0
    } ;

static yyconst YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    6,    7,    8,    9,   10,    1,   11,    1,
        1,    1,   12,    1,   13,   14,    1,   15,   15,   15,
       15,   15,   15,   15,   15,   15,   15,    1,    1,   16,
       17,   18,    1,    1,   19,   20,   21,   22,   23,   24,
       25,   26,   27,   28,   29,   30,   31,   32,   33,   34,
       35,   36,   37,   38,   39,   40,   41,   42,   43,   44,
       45,   46,   47,    1,   48,    1,   49,   50,   51,   52,

       53,   54,   55,   56,   57,   58,   59,   60,   61,   62,
       63,   64,   65,   66,   67,   68,   69,   70,   71,   72,
       73,   74,   14,   14,   14,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst YY_CHAR yy_meta[75] =
    {   0,
        1,    2,    3,    2,    2,    1,    1,    2,    1,    1,
        1,    2,    4,    2,    4,    1,    1,    1,    5,    5,
        5,    6,    6,    5,    6,    5,    5,    6,    5,    5,
        6,    6,    6,    5,    6,    6,    5,    5,    6,    6,
        5,    6,    6,    6,    1,    2,    1,    6,    6,    6,
        6,    6,    6,    6,    6,    6,    6,    6,    6,    6,
        6,    6,    6,    6,    6,    6,    6,    6,    6,    6,
        6,    5,    6,    6
    } ;

static yyconst flex_uint16_t yy_base[1064] =
    {   0,
        0,   73,  102,   77, 1254, 1255,   75, 1255, 1250, 1235,
     1244,    0, 1204, 1234, 1233,   78,   66, 1230, 1229, 1215,
     1208,   57,   63,   59,   64,  101,    0,   63,   79,  119,
       94, 1223, 1209,  122,  123,  121, 1222,  104,  105,  100,
      124,   90,  129,  137, 1174,   84,  117, 1176,  139,  150,
      151,  151,  156, 1169,  163,  168,  166,   56, 1184, 1183,
      232, 1232,  216, 1255, 1231,  242,  248,  251,  264,  196,
      155,  167,  208,  228,  241, 1218,  249,  242,  195,  277,
      284,  223,  319,  334,  257, 1255, 1255, 1225, 1255,    0,
     1220, 1219, 1214,    0, 1213, 1255,  298, 1212, 1255, 1255,

     1255, 1255, 1188,  263, 1188,  264, 1200, 1190, 1203, 1184,
     1195, 1192, 1199,  270, 1185, 1183, 1185, 1195,    0, 1186,
     1190, 1171, 1177, 1165, 1171, 1175, 1174, 1174,  280, 1176,
      292, 1171,  301, 1169, 1162, 1168, 1180, 1178, 1170,  259,
        0, 1177, 1165,  203,  304,  272, 1121, 1143, 1132, 1138,
     1141,  288, 1121, 1125, 1121, 1124, 1123, 1135, 1117, 1119,
      308, 1115, 1109, 1106, 1111, 1110, 1116, 1120, 1111, 1113,
     1111, 1111,  234,  281,  296,  299, 1117,  282, 1103, 1111,
     1096,   81,  315, 1115,  324,   26, 1103, 1102, 1102, 1093,
      330, 1103, 1107, 1093, 1109, 1104, 1107,  281,  333, 1100,

     1102, 1098, 1090,  342,  323,  321, 1082, 1081, 1083, 1084,
      345,  350,    0, 1081,  332,  407, 1143, 1142, 1255,  363,
     1255, 1255, 1141,  411,  415,  416, 1128,    0,  412,  390,
      396,  404,  415, 1127,  410,  420,  421,  422,  423,  424,
        0,    0, 1255, 1138,    0, 1255, 1129, 1128, 1123, 1118,
     1104, 1116, 1111, 1095, 1096, 1112, 1094, 1088, 1105, 1091,
     1088, 1100,    0, 1092, 1102, 1091, 1099, 1080, 1081, 1096,
     1094, 1082, 1092, 1077, 1090, 1075, 1088, 1091, 1061, 1085,
     1077, 1068, 1083, 1077, 1073, 1071, 1077, 1071, 1072, 1062,
     1059, 1073, 1059, 1060, 1063,  435, 1037,    0, 1042,    0,

     1027, 1036, 1026, 1028, 1019, 1023, 1021, 1015, 1023,  385,
     1030, 1012, 1016, 1027, 1010, 1016, 1011, 1020, 1007, 1005,
     1009,    0, 1002, 1001, 1011, 1001, 1014,  998, 1015,  383,
     1010,  999,  392, 1012,  989, 1005, 1006, 1000,  988,    0,
     1003, 1003,  996,  999,  989,    0,  982,  983,  991,  994,
        0,  987,  992,  981,  993,  983,  988,  987,  378,  986,
      970,  977,  973,  974,  404,  966,  408,  980,  970,  982,
      979,  968,  966,  970,  974,  392,  956,  967,  967,  971,
      952,  969,  953,  956,  964,  950,  395,  958,  946,  964,
      950,  945,    0,  946,  956,  939,  950,  943,  948,  936,

      935,    0,  462,  448,  453,  971,  454,  456,  434,  455,
     1255,  965,  979,  970,    0,  979,  970,  957,    0,  975,
        0,  975,    0,  956,  954,  953,  967,    0,  966,  940,
      964,  956,    0,  944,  965,  947,  944,    0,  947,  452,
      959,    0,  960,  945,  944,  957,  953,  950,    0,  937,
      939,  950,  936,  950,    0,  941,  468, 1255,  905,  900,
      899,  911,  908,  909,  894,  908,  907,  895,  904,  903,
        0,  902,  901,  886,  892,  898,  893,  889,  879,  886,
      893,    0,    0,    0,  881,  895,  890,  889,  881,  422,
      887,  882,  886,  880,  883,  868,    0,  921,  879,  858,

      874,  866,  878,  861,  872,  873,    0,  872,  856,    0,
      870,  873,  859,  862,    0,  429,  852,  850,  844,  850,
      858,  851,  864,  849,    0,  855,  842,  849,  857,    0,
      847,  853,  856,  836,  854,  417,  853,    0,  841,  830,
      831,  835,  844,  828,  842,  846,  842,  824,  829,  821,
      837,  832,  821,  824,  836,  820,    0,  817,  822,  824,
      426,  823,    0, 1255,  876,  463,  859,  466,  475,  476,
        0,  851,    0,  849,  853,  844,  837,  832,    0,  852,
      843,  831,    0,  837,  831,    0,  847,  840,  845,  840,
        0,  835,  842,  822,  829,  827,  825,  835,  822,  824,

        0,  820,  826,  818,  823,  825,    0,    0,  795,  783,
      793,    0,  792,  791,    0,  782,  780,  789,  780,  773,
        0,  785,  785,  781,  782,  767,  784,  780,  764,  760,
      440,    0,  776,  776,  774,  760,  763,  770,  770,  749,
      768,  435,  760,  756,  758,  754,  763,  758,  745,  761,
      757,  758,  758,  741,  741,  754,  740,  752,    0,  751,
      739,  753,  746,  734,  735,  749,    0,  731,  743,  727,
      721,  739,  728,  734,  730,  732,  727,  721,  737,  732,
        0,  721,    0,  714,  714,  713,  712,  712,  725,  725,
      443,    0,  723,  722,  717,  720,  705,  711,  708,  712,

        0,  717,  733,  483,  490,    0,  734,  732,  726,  736,
      735,  734,  727,  723,  739,    0,  724,  712,   81,  122,
      205,  226,    0,    0,  311,    0,  350,  460,  483,  476,
        0,  472,  478,  468,  463,    0,    0,  461,  464,    0,
        0,    0,  457,    0,    0,    0,  456,  458,  467,  447,
        0,  469,  470,    0,  458,    0,    0,  474,    0,  471,
      470,  466,  480,  478,  478,  475,  470,  472,  482,  473,
      470,  488,  479,    0,  483,  489,    0,  473,  475,  493,
      488,  476,  481,  495,  489,  488,    0,    0,  491,  503,
      489,    0,  480,  486,  492,  489,    0,  496,  514,  505,

      495,  510,  497,  503,    0,  499,  509,  510,    0,    0,
      511,  515,    0,  518,  509,  520,  520,  521,  522,  508,
      528,    0,  563,  564,  557,  545,    0,  560,  551,  552,
      553,  543,  553,  559,    0,  562,    0,  565,  554,  571,
      545,  558,    0,    0,  557,    0,    0,  536,    0,    0,
      544,  545,  546,  548,  548,    0,    0,  539,  535,    0,
      544,  537,  540,    0,  554,  554,  547,  543,    0,  552,
      546,  554,  566,  553,    0,  551,  565,  551,  568,  568,
        0,    0,    0,    0,  565,  559,  561,  572,  566,  574,
      555,  576, 1255,  577,    0,    0,  579,    0,  583,  570,

      579,  575,  563,    0,    0,    0,  585,  586,  587,  587,
      581,  606,    0,  618,  619,    0,    0,    0,    0,    0,
      601,  627,  606,  615,  611,    0,  602,    0,  599,  600,
      591,    0,    0,  591,    0,  595,    0,  604,  589,  602,
      593,  611,  594,  605,  610,  598,  603,  613,  601,    0,
        0,  608,  614,  606,  605,  620,    0,  621,    0,    0,
      622,    0,  611,  614,  621,  618,    0,    0,    0,    0,
      627,    0,    0,  657,    0,  658,  662,  664,  648,  662,
      650,    0,    0,  619,  634,    0,    0,    0,  621,    0,
      630,    0,  641,    0,    0,    0,    0,    0,    0,  630,

      640,  626,    0,    0,    0,  628,    0,  628,    0,    0,
        0,    0,  667,  668,  663,  664,  678,    0,    0,    0,
        0,  642,  650,  652,    0,    0,  652,  683,  677,  681,
      673,  685,  658,  660,    0,  661,    0,    0,  692,  696,
      689,  650,    0,    0,  685,  692,  687,    0,  685,  690,
      691,  687,    0,    0,    0, 1255,  724,  726,  732,  735,
      741,  746,  751
    } ;

static yyconst flex_int16_t yy_def[1064] =
    {   0,
     1056,    1,    1,    3, 1056, 1056, 1056, 1056, 1056, 1056,
     1057, 1058, 1059, 1056, 1060, 1060, 1056, 1056, 1056, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1056, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1056, 1061, 1060, 1056, 1056, 1062, 1062, 1062, 1060,   69,
       69,   69,   69, 1060,   69,   69,   69,   69,   69,   69,
       69,   69, 1062, 1061, 1056, 1056, 1056, 1057, 1056, 1058,
     1056, 1063, 1056, 1060, 1060, 1056, 1060, 1060, 1056, 1056,

     1056, 1056, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1056, 1056, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,

     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1056, 1061, 1061, 1056, 1060,
     1056, 1056, 1056,   83,   83,   83,   69,   69,   69,   69,
       69, 1060,   69,   69,   69,   69,   69,   69,   69,   69,
       83,   84, 1056, 1061,   84, 1056, 1056, 1056, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1056, 1060, 1060, 1060, 1060,

     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,

     1060, 1060, 1060,   69,   69, 1060,   69,   69,   69,   69,
     1056, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1056, 1056, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,

     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1056, 1056,   69, 1060,   69,   69,   69,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,

     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,

     1060, 1060, 1060,   69,   69, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,

     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060,   69,   69, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1056, 1060, 1060, 1060, 1060, 1060, 1060, 1060,

     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,

     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060, 1060,
     1060, 1060, 1060, 1060, 1060,    0, 1056, 1056, 1056, 1056,
     1056, 1056, 1056
    } ;

static yyconst flex_uint16_t yy_nxt[1330] =
    {   0,
        6,    7,    8,    9,    7,   10,   11,    6,   12,    6,
       13,   14,   15,    6,   16,   17,   18,   19,   20,   21,
       22,   23,   24,   25,   26,   27,   28,   27,   27,   29,
       30,   31,   32,   33,   27,   34,   35,   36,   27,   27,
       37,   27,   27,   27,   38,    6,    6,   27,   39,   40,
       41,   42,   43,   44,   45,   46,   47,   48,   27,   49,
       50,   51,   52,   53,   54,   55,   56,   57,   58,   59,
       60,   27,   27,   27,   61,  105,   85,   61,   61,   85,
       62,   83,   99,  100,   84,  107,  119,   96,  110,  106,
      111,  356,   97,  113,  120,  108,  114,  121,  109,  357,

      112,  122,  115,   63,   64,   65,   66,   63,  144,   67,
      836,  123,  128,   68,   69,   67,   70,  212,  145,  213,
       71,   72,   73,  116,   74,   75,  129,   76,   77,   98,
       76,   78,  175,  117,  347,   79,  118,  124,   80,   81,
      132,  125,   82,  140,  133,  126,  176,   67,  135,  136,
      348,  127,  163,  141,  134,  164,  142,  837,  165,  152,
      137,  138,  153,  139,  146,  154,  147,  177,  155,  227,
      148,  149,  156,   76,  150,  151,  157,  166,  178,  158,
      159,  227,  179,  160,  230,  170,  161,  181,  167,  171,
      168,  182,  162,  172,  169,  183,  173,  185,  186,  189,

      192,  184,  104,  190,  194,   96,  187,  144,  195,  227,
      229,  198,  188,  191,  193,  199,  203,  145,  209,  200,
      204,  196,  227,  205,  201,  202,  231,  131,  210,  838,
      206,  211,  207,  216,  220,  208,  216,  227,  125,  217,
      106,  240,  126,   85,  222,  223,  224,   98,  127, 1056,
      222,  223, 1056,  222,  223,  227,  227,  110,   85,  232,
      235,   85,  839,  227,  122,  226,  222,  223,  225,  112,
      233,  225,  234,  114,  123,  225,  227,  225,  228,  115,
      120,  251,  227,  227,  227,  252,  331,  227,  292,  227,
      227,  227,  227,  227,  293,  254,  332,  227,  227,  255,

      227,  227,  236,  237,  227,  263,  140,   96,  264,  225,
      278,  279,   97,  296,  238,  138,  141,  239,  145,  142,
      216,  222,  223,  241,  281,  284,  242,  282,  297,  333,
      342,  298,  374,  334,  285,  227,  243,  244,  245,  299,
      305,  245,  375,  335,  306,  245,  245,  245,  245,   98,
      307,  343,  245,  245,  245,  336,  316,  245,  840,  245,
      245,  337,  245,  245,  338,  339,  340,  245,  317,  318,
      245,  245,  841,  319,  245,  349,  350,  353,  362,  245,
      388,  363,  351,  376,  354,  386,  355,  377,  387,  389,
      364,  365,  383,  394,  384,  366,  403,  367,  401,  402,

      396,  385,  378,  397,  227,  245,  273,  398,  216,  399,
      227,  216,   85,  395,  217,  224, 1056, 1056,  225,  225,
      225,   96,  225,  225,  227,  406,  229,  404,  260,  227,
      226,  270,  405,  407,  227,  227,  227,  227,  227,  457,
      408,  470,  490,  494,  518,  519,  471,  537,  227,  409,
      491,  549,  288,  410,  524,  527,  525,  550,  287,  538,
      528,  495,  227,   98,  564,  565,  566,  227,  227,  227,
      227,  569,  457,  592,  634,  415,  676,  227,  424,  677,
      227,  458,  568,  657,  570,  593,  700,  635,  658,  227,
      227,  754,  842,  701,  765,  704,  811,  227,  571,  812,

      766,  601,  705,  755,  227,  843,  844,  845,  823,  846,
      847,  848,  849,  824,  458,  850,  851,  852,  853,  854,
      855,  856,  857,  858,  859,  860,  861,  862,  863,  864,
      865,  866,  867,  868,  869,  870,  871,  872,  873,  874,
      875,  876,  877,  878,  879,  880,  881,  882,  883,  884,
      885,  886,  887,  888,  889,  890,  891,  892,  893,  894,
      895,  896,  897,  898,  899,  900,  901,  902,  903,  904,
      905,  906,  907,  908,  909,  910,  911,  227,  227,  912,
      913,  914,  915,  916,  917,  918,  919,  920,  921,  922,
      923,  924,  925,  926,  927,  928,  929,  930,  931,  932,

      933,  934,  935,  936,  937,  938,  847,  939,  940,  941,
      942,  943,  944,  945,  946,  947,  948,  949,  950,  951,
      952,  953,  954,  955,  956,  957,  958,  959,  960,  961,
      962,  963,  964,  965,  966,  967,  968,  969,  970,  971,
      972,  973,  974,  975,  976,  977,  978,  979,  980,  981,
      982,  983,  984,  985,  986,  987,  988,  989,  990,  991,
      992,  993,  994,  995,  996,  997,  998,  999, 1000, 1001,
     1002, 1003, 1004, 1005, 1006, 1007, 1008, 1009, 1010, 1011,
     1012, 1013, 1014, 1015, 1016, 1017, 1018, 1019, 1020, 1021,
     1022, 1023, 1024, 1025, 1026, 1027, 1028, 1029, 1030, 1031,

     1032, 1033, 1034, 1035, 1036, 1037, 1038, 1039, 1040, 1041,
     1042, 1043, 1044, 1045, 1046, 1047, 1048, 1049, 1050, 1051,
     1052, 1053, 1054, 1055,   88,   88,   88,   88,   88,   88,
       90,   90,   91,   91,  835,   91,   91,   91,   94,   94,
       94,  218,  218,  218,  218,  218,  218,  225,  225,  225,
      225,  247,  247,  834,  247,  247,  247,  833,  832,  831,
      830,  829,  828,  827,  826,  825,  822,  821,  820,  819,
      818,  817,  816,  815,  814,  813,  810,  809,  808,  807,
      806,  805,  804,  803,  802,  801,  800,  799,  798,  797,
      796,  795,  794,  793,  792,  791,  790,  789,  788,  787,

      786,  785,  784,  783,  782,  781,  780,  779,  778,  777,
      776,  775,  774,  773,  772,  771,  770,  769,  768,  767,
      764,  763,  762,  761,  760,  759,  758,  757,  756,  753,
      752,  751,  750,  749,  748,  747,  746,  745,  744,  743,
      742,  741,  740,  739,  738,  737,  736,  735,  734,  733,
      732,  731,  730,  729,  728,  727,  726,  725,  724,  723,
      722,  721,  720,  719,  718,  717,  716,  715,  714,  713,
      712,  711,  710,  709,  708,  707,  706,  703,  564,  702,
      699,  698,  697,  696,  695,  694,  693,  692,  691,  690,
      689,  688,  687,  686,  685,  684,  683,  682,  681,  680,

      679,  678,  675,  674,  673,  672,  671,  670,  669,  668,
      667,  666,  665,  664,  663,  662,  661,  660,  659,  656,
      655,  654,  653,  652,  651,  650,  649,  648,  647,  646,
      645,  644,  643,  642,  641,  640,  639,  638,  637,  636,
      633,  632,  631,  630,  629,  628,  627,  626,  625,  624,
      623,  622,  621,  620,  619,  618,  617,  616,  615,  614,
      613,  612,  611,  610,  609,  608,  607,  606,  605,  604,
      603,  602,  601,  600,  599,  598,  597,  596,  595,  594,
      591,  590,  589,  588,  587,  586,  585,  584,  583,  582,
      581,  580,  579,  578,  577,  576,  575,  574,  573,  572,

      571,  567,  563,  562,  561,  560,  559,  558,  557,  556,
      555,  554,  553,  552,  551,  548,  547,  546,  545,  544,
      543,  542,  541,  540,  539,  536,  535,  534,  533,  532,
      531,  530,  529,  526,  523,  522,  521,  520,  438,  517,
      516,  515,  514,  513,  512,  511,  510,  509,  508,  507,
      506,  505,  504,  503,  502,  501,  500,  499,  498,  497,
      496,  493,  492,  489,  488,  487,  486,  485,  484,  483,
      482,  481,  480,  479,  478,  477,  476,  475,  474,  473,
      472,  469,  468,  467,  466,  465,  464,  463,  462,  461,
      460,  459,  456,  455,  454,  453,  452,  451,  450,  449,

      448,  447,  446,  445,  444,  443,  442,  441,  440,  439,
      438,  437,  436,  435,  434,  433,  432,  431,  430,  429,
      428,  427,  426,  425,  424,  423,  422,  421,  420,  419,
      418,  417,  416,  415,  414,  413,  412,  249,  411,  411,
      243,  227,  227,  222,  219,  219,  400,  393,  392,  391,
      390,  382,  381,  380,  379,  373,  372,  371,  370,  369,
      368,  361,  360,  359,  358,  352,  346,  345,  344,  341,
      330,  329,  328,  327,  326,  325,  324,  323,  322,  321,
      320,  315,  314,  313,  312,  311,  310,  309,  308,  304,
      303,  302,  301,  300,  295,  294,  291,  290,  289,  288,

      287,  286,  283,  280,  277,  276,  275,  274,  273,  272,
      271,  270,  269,  268,  267,  266,  265,  262,  261,  260,
      259,  258,  257,  256,  253,  250,  249,   95,   93,  248,
      246,   89,  227,  221,  219,  215,  214,  197,  180,  174,
      143,  131,  130,  104,  103,  102,  101,   95,   93,   92,
       89,   87,   86, 1056,    5, 1056, 1056, 1056, 1056, 1056,
     1056, 1056, 1056, 1056, 1056, 1056, 1056, 1056, 1056, 1056,
     1056, 1056, 1056, 1056, 1056, 1056, 1056, 1056, 1056, 1056,
     1056, 1056, 1056, 1056, 1056, 1056, 1056, 1056, 1056, 1056,
     1056, 1056, 1056, 1056, 1056, 1056, 1056, 1056, 1056, 1056,

     1056, 1056, 1056, 1056, 1056, 1056, 1056, 1056, 1056, 1056,
     1056, 1056, 1056, 1056, 1056, 1056, 1056, 1056, 1056, 1056,
     1056, 1056, 1056, 1056, 1056, 1056, 1056, 1056, 1056
    } ;

static yyconst flex_int16_t yy_chk[1330] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    2,   22,    7,    2,    4,    7,
        2,    4,   17,   17,    4,   23,   28,   16,   24,   22,
       24,  186,   16,   25,   28,   23,   25,   29,   23,  186,

       24,   29,   25,    2,    3,    3,    3,    4,   38,    3,
      719,   29,   31,    3,    3,    3,    3,   58,   38,   58,
        3,    3,    3,   26,    3,    3,   31,    3,    3,   16,
        3,    3,   46,   26,  182,    3,   26,   30,    3,    3,
       34,   30,    3,   36,   34,   30,   46,    3,   35,   35,
      182,   30,   42,   36,   34,   42,   36,  720,   42,   40,
       35,   35,   40,   35,   39,   40,   39,   47,   40,   71,
       39,   39,   41,    3,   39,   39,   41,   43,   47,   41,
       41,   72,   47,   41,   71,   44,   41,   49,   43,   44,
       43,   49,   41,   44,   43,   49,   44,   50,   50,   51,

       52,   49,   72,   51,   53,   70,   50,  144,   53,   79,
       70,   55,   50,   51,   52,   55,   56,  144,   57,   55,
       56,   53,   73,   56,   55,   55,   73,   79,   57,  721,
       56,   57,   56,   61,   63,   56,   61,   82,   63,   61,
       73,   82,   63,   66,   66,   66,   66,   70,   63,   67,
       67,   67,   68,   68,   68,   75,   78,   74,   85,   74,
       78,   85,  722,   77,   78,   68,   69,   69,   69,   74,
       75,   69,   77,   75,   78,   69,   69,   69,   69,   75,
       77,  104,   69,   69,   69,  104,  173,   69,  140,   69,
       69,   80,   69,   69,  140,  106,  173,   69,   81,  106,

       69,   69,   80,   80,   69,  114,   81,   97,  114,   69,
      129,  129,   97,  145,   80,   80,   81,   80,  145,   81,
       83,   83,   83,   83,  131,  133,   83,  131,  146,  174,
      178,  146,  198,  174,  133,   69,   84,   84,   84,  146,
      152,   84,  198,  174,  152,   84,   84,   84,   84,   97,
      152,  178,   84,   84,   84,  175,  161,   84,  725,   84,
       84,  175,   84,   84,  176,  176,  176,   84,  161,  161,
       84,   84,  727,  161,   84,  183,  183,  185,  191,   84,
      206,  191,  183,  199,  185,  205,  185,  199,  205,  206,
      191,  191,  204,  211,  204,  191,  220,  191,  215,  215,

      212,  204,  199,  212,  230,   84,  220,  212,  216,  212,
      231,  216,  224,  211,  216,  224,  225,  226,  224,  225,
      226,  229,  225,  226,  235,  232,  229,  230,  232,  233,
      226,  235,  231,  233,  236,  237,  238,  239,  240,  296,
      238,  310,  330,  333,  359,  359,  310,  376,  409,  239,
      330,  387,  237,  240,  365,  367,  365,  387,  236,  376,
      367,  333,  404,  229,  403,  403,  404,  405,  407,  410,
      408,  409,  457,  440,  490,  405,  536,  566,  407,  536,
      568,  296,  408,  516,  410,  440,  561,  490,  516,  569,
      570,  631,  728,  561,  642,  569,  691,  704,  566,  691,

      642,  568,  570,  631,  705,  729,  730,  732,  704,  733,
      734,  735,  738,  705,  457,  739,  743,  747,  748,  749,
      750,  752,  753,  755,  758,  760,  761,  762,  763,  764,
      765,  766,  767,  768,  769,  770,  771,  772,  773,  775,
      776,  778,  779,  780,  781,  782,  783,  784,  785,  786,
      789,  790,  791,  793,  794,  795,  796,  798,  799,  800,
      801,  802,  803,  804,  806,  807,  808,  811,  812,  814,
      815,  816,  817,  818,  819,  820,  821,  823,  824,  825,
      826,  828,  829,  830,  831,  832,  833,  834,  836,  838,
      839,  840,  841,  842,  845,  848,  851,  852,  853,  854,

      855,  858,  859,  861,  862,  863,  824,  865,  866,  867,
      868,  870,  871,  872,  873,  874,  876,  877,  878,  879,
      880,  885,  886,  887,  888,  889,  890,  891,  892,  894,
      897,  899,  900,  901,  902,  903,  907,  908,  909,  910,
      911,  912,  914,  915,  921,  922,  923,  924,  925,  927,
      929,  930,  931,  934,  936,  938,  939,  940,  941,  942,
      943,  944,  945,  946,  947,  948,  949,  952,  953,  954,
      955,  956,  958,  961,  963,  964,  965,  966,  971,  974,
      976,  977,  978,  979,  980,  981,  984,  985,  989,  991,
      993, 1000, 1001, 1002, 1006, 1008, 1013, 1014, 1015, 1016,

     1017, 1022, 1023, 1024, 1027, 1028, 1029, 1030, 1031, 1032,
     1033, 1034, 1036, 1039, 1040, 1041, 1042, 1045, 1046, 1047,
     1049, 1050, 1051, 1052, 1057, 1057, 1057, 1057, 1057, 1057,
     1058, 1058, 1059, 1059,  718, 1059, 1059, 1059, 1060, 1060,
     1060, 1061, 1061, 1061, 1061, 1061, 1061, 1062, 1062, 1062,
     1062, 1063, 1063,  717, 1063, 1063, 1063,  715,  714,  713,
      712,  711,  710,  709,  708,  707,  703,  702,  700,  699,
      698,  697,  696,  695,  694,  693,  690,  689,  688,  687,
      686,  685,  684,  682,  680,  679,  678,  677,  676,  675,
      674,  673,  672,  671,  670,  669,  668,  666,  665,  664,

      663,  662,  661,  660,  658,  657,  656,  655,  654,  653,
      652,  651,  650,  649,  648,  647,  646,  645,  644,  643,
      641,  640,  639,  638,  637,  636,  635,  634,  633,  630,
      629,  628,  627,  626,  625,  624,  623,  622,  620,  619,
      618,  617,  616,  614,  613,  611,  610,  609,  606,  605,
      604,  603,  602,  600,  599,  598,  597,  596,  595,  594,
      593,  592,  590,  589,  588,  587,  585,  584,  582,  581,
      580,  578,  577,  576,  575,  574,  572,  567,  565,  562,
      560,  559,  558,  556,  555,  554,  553,  552,  551,  550,
      549,  548,  547,  546,  545,  544,  543,  542,  541,  540,

      539,  537,  535,  534,  533,  532,  531,  529,  528,  527,
      526,  524,  523,  522,  521,  520,  519,  518,  517,  514,
      513,  512,  511,  509,  508,  506,  505,  504,  503,  502,
      501,  500,  499,  498,  496,  495,  494,  493,  492,  491,
      489,  488,  487,  486,  485,  481,  480,  479,  478,  477,
      476,  475,  474,  473,  472,  470,  469,  468,  467,  466,
      465,  464,  463,  462,  461,  460,  459,  456,  454,  453,
      452,  451,  450,  448,  447,  446,  445,  444,  443,  441,
      439,  437,  436,  435,  434,  432,  431,  430,  429,  427,
      426,  425,  424,  422,  420,  418,  417,  416,  414,  413,

      412,  406,  401,  400,  399,  398,  397,  396,  395,  394,
      392,  391,  390,  389,  388,  386,  385,  384,  383,  382,
      381,  380,  379,  378,  377,  375,  374,  373,  372,  371,
      370,  369,  368,  366,  364,  363,  362,  361,  360,  358,
      357,  356,  355,  354,  353,  352,  350,  349,  348,  347,
      345,  344,  343,  342,  341,  339,  338,  337,  336,  335,
      334,  332,  331,  329,  328,  327,  326,  325,  324,  323,
      321,  320,  319,  318,  317,  316,  315,  314,  313,  312,
      311,  309,  308,  307,  306,  305,  304,  303,  302,  301,
      299,  297,  295,  294,  293,  292,  291,  290,  289,  288,

      287,  286,  285,  284,  283,  282,  281,  280,  279,  278,
      277,  276,  275,  274,  273,  272,  271,  270,  269,  268,
      267,  266,  265,  264,  262,  261,  260,  259,  258,  257,
      256,  255,  254,  253,  252,  251,  250,  249,  248,  247,
      244,  234,  227,  223,  218,  217,  214,  210,  209,  208,
      207,  203,  202,  201,  200,  197,  196,  195,  194,  193,
      192,  190,  189,  188,  187,  184,  181,  180,  179,  177,
      172,  171,  170,  169,  168,  167,  166,  165,  164,  163,
      162,  160,  159,  158,  157,  156,  155,  154,  153,  151,
      150,  149,  148,  147,  143,  142,  139,  138,  137,  136,

      135,  134,  132,  130,  128,  127,  126,  125,  124,  123,
      122,  121,  120,  118,  117,  116,  115,  113,  112,  111,
      110,  109,  108,  107,  105,  103,   98,   95,   93,   92,
       91,   88,   76,   65,   62,   60,   59,   54,   48,   45,
       37,   33,   32,   21,   20,   19,   18,   15,   14,   13,
       11,   10,    9,    5, 1056, 1056, 1056, 1056, 1056, 1056,
     1056, 1056, 1056, 1056, 1056, 1056, 1056, 1056, 1056, 1056,
     1056, 1056, 1056, 1056, 1056, 1056, 1056, 1056, 1056, 1056,
     1056, 1056, 1056, 1056, 1056, 1056, 1056, 1056, 1056, 1056,
     1056, 1056, 1056, 1056, 1056, 1056, 1056, 1056, 1056, 1056,

     1056, 1056, 1056, 1056, 1056, 1056, 1056, 1056, 1056, 1056,
     1056, 1056, 1056, 1056, 1056, 1056, 1056, 1056, 1056, 1056,
     1056, 1056, 1056, 1056, 1056, 1056, 1056, 1056, 1056
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
/* NetHack 3.6  lev_comp.l	$NHDT-Date: 1543372935 2018/11/28 02:42:15 $  $NHDT-Branch: NetHack-3.6.2-beta01 $:$NHDT-Revision: 1.29 $ */
/*	Copyright (c) 1989 by Jean-Christophe Collet */
/* NetHack may be freely redistributed.  See license for details. */

#define LEV_LEX_C

#include "hack.h"
#include "lev_comp.h"
#include "sp_lev.h"

/* Most of these don't exist in flex, yywrap is macro and
 * yyunput is properly declared in flex.skel.
 */
#if !defined(FLEX_SCANNER) && !defined(FLEXHACK_SCANNER)
int FDECL(yyback, (int *,int));
int NDECL(yylook);
int NDECL(yyinput);
int NDECL(yywrap);
int NDECL(yylex);
	/* Traditional lexes let yyunput() and yyoutput() default to int;
	 * newer ones may declare them as void since they don't return
	 * values.  For even more fun, the lex supplied as part of the
	 * newer unbundled compiler for SunOS 4.x adds the void declarations
	 * (under __STDC__ or _cplusplus ifdefs -- otherwise they remain
	 * int) while the bundled lex and the one with the older unbundled
	 * compiler do not.  To detect this, we need help from outside --
	 * sys/unix/Makefile.utl.
	 *
	 * Digital UNIX is difficult and still has int in spite of all
	 * other signs.
	 */
# if defined(NeXT) || defined(SVR4) || defined(_AIX32)
#  define VOIDYYPUT
# endif
# if !defined(VOIDYYPUT) && defined(POSIX_TYPES)
#  if !defined(BOS) && !defined(HISX) && !defined(_M_UNIX) && !defined(VMS)
#   define VOIDYYPUT
#  endif
# endif
# if !defined(VOIDYYPUT) && defined(WEIRD_LEX)
#  if defined(SUNOS4) && defined(__STDC__) && (WEIRD_LEX > 1)
#   define VOIDYYPUT
#  endif
# endif
# if defined(VOIDYYPUT) && defined(__osf__)
#  undef VOIDYYPUT
# endif
# ifdef VOIDYYPUT
void FDECL(yyunput, (int));
void FDECL(yyoutput, (int));
# else
int FDECL(yyunput, (int));
int FDECL(yyoutput, (int));
# endif

#else	/* !FLEX_SCANNER && !FLEXHACK_SCANNER */
/* most recent flex allows suppressing yyunput() altogether when not needed */
#define YY_NO_UNPUT
#define YY_NO_INPUT
#endif

#if defined(FLEX_SCANNER) || defined(FLEXHACK_SCANNER)
/* older flex wants this */
#define YY_MALLOC_DECL  genericptr_t FDECL(malloc, (size_t)); \
                        genericptr_t FDECL(realloc, (genericptr_t, size_t));
/* newer flex assumes <stdlib.h> so needs this in case it's been suppressed */
YY_MALLOC_DECL
#endif

void FDECL(init_yyin, (FILE *));
void FDECL(init_yyout, (FILE *));

long NDECL(handle_varstring_check);
long FDECL(corefunc_str_check, (char *, long));

extern void VDECL(lc_error, (const char *, ...));
extern struct lc_vardefs *FDECL(vardef_defined,(struct lc_vardefs *,char *, int));

extern struct lc_vardefs *vardefs;

extern long FDECL(method_defined, (char *, long, long *));

void FDECL(savetoken, (char *));
void NDECL(newline);
void FDECL(advancepos, (char *));

/*
 * This doesn't always get put in lev_comp.h
 * (esp. when using older versions of bison).
 */
extern YYSTYPE yylval;

int nh_line_number = 1;
int token_start_pos = 0;
char curr_token[512];
static char map[4096];
static int map_cnt = 0;

FILE *orig_yyin = NULL;

#define ST_RET(x) do { savetoken(yytext); return x; } while (0);
#define ST_RETF(y, x) do { savetoken(yytext); y; return x; } while (0);

#define INITIAL 0
#define MAPC 1

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy FDECL(FDECL_dummy, (void ));
int yyget_debug FDECL(FDECL_dummy, (void ));
void yyset_debug FDECL(FDECL_dummy, (int debug_flag  ));
YY_EXTRA_TYPE yyget_extra FDECL(FDECL_dummy, (void ));
void yyset_extra FDECL(FDECL_dummy, (YY_EXTRA_TYPE user_defined  ));
FILE *yyget_in FDECL(FDECL_dummy, (void ));
void yyset_in  FDECL(FDECL_dummy, (FILE * _in_str  ));
FILE *yyget_out FDECL(FDECL_dummy, (void ));
void yyset_out  FDECL(FDECL_dummy, (FILE * _out_str  ));
yy_size_t yyget_leng FDECL(FDECL_dummy, (void ));
char *yyget_text FDECL(FDECL_dummy, (void ));
int yyget_lineno FDECL(FDECL_dummy, (void ));
void yyset_lineno FDECL(FDECL_dummy, (int _line_number  ));

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
extern int yywrap FDECL(FDECL_dummy, (void ));
#endif

#ifndef YY_NO_UNPUT

void yyunput FDECL(FDECL_dummy, (int c,char *buf_ptr  ));
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy FDECL(FDECL_dummy, (char *,yyconst char *,int ));
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen FDECL(FDECL_dummy, (yyconst char * ));
#endif

#ifndef YY_NO_INPUT

static int input FDECL(FDECL_dummy, (void ));

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex FDECL(FDECL_dummy, (void));

#define YY_DECL int yylex ()
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	if ( yyleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(yytext[yyleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE );
		}

		yy_load_buffer_state( );
		}

	{

	while ( /*CONSTCOND*/1 )    /* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 1057 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1255 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
{
		  savetoken(yytext);
		  BEGIN(INITIAL);
		  yylval.map = (char *) alloc(map_cnt + 1);
		  (void) strncpy(yylval.map, map, map_cnt);
		  yylval.map[map_cnt] = 0;
		  map_cnt = 0;
		  return MAP_ID;
		}
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
{
		  int len = yyleng;
		  savetoken(yytext);
		  /* convert \r\n to \n */
		  if (len >= 2 && yytext[len - 2] == '\r')
		      len -= 1;
		  (void) strncpy(map + map_cnt, yytext, len);
		  map_cnt += len;
		  map[map_cnt - 1] = '\n';
		  map[map_cnt] = '\0';
		  newline();
		}
	YY_BREAK
case 3:
/* rule 3 can match eol */
YY_RULE_SETUP
{ savetoken(yytext); newline(); }
	YY_BREAK
case 4:
YY_RULE_SETUP
ST_RET(MESSAGE_ID);
	YY_BREAK
case 5:
YY_RULE_SETUP
ST_RET(NOMAP_ID);
	YY_BREAK
case 6:
YY_RULE_SETUP
ST_RET(MAZE_ID);
	YY_BREAK
case 7:
YY_RULE_SETUP
ST_RET(LEVEL_ID);
	YY_BREAK
case 8:
YY_RULE_SETUP
ST_RET(LEV_INIT_ID);
	YY_BREAK
case 9:
YY_RULE_SETUP
ST_RET(MAZE_GRID_ID);
	YY_BREAK
case 10:
YY_RULE_SETUP
ST_RET(SOLID_FILL_ID);
	YY_BREAK
case 11:
YY_RULE_SETUP
ST_RET(MINES_ID);
	YY_BREAK
case 12:
YY_RULE_SETUP
ST_RET(ROGUELEV_ID);
	YY_BREAK
case 13:
YY_RULE_SETUP
ST_RET(FLAGS_ID);
	YY_BREAK
case 14:
YY_RULE_SETUP
ST_RET(GEOMETRY_ID);
	YY_BREAK
case 15:
/* rule 15 can match eol */
YY_RULE_SETUP
{ savetoken(yytext); BEGIN(MAPC); newline(); }
	YY_BREAK
case 16:
YY_RULE_SETUP
ST_RET(object_ID);
	YY_BREAK
case 17:
YY_RULE_SETUP
ST_RET(OBJECT_ID);
	YY_BREAK
case 18:
YY_RULE_SETUP
ST_RET(COBJECT_ID);
	YY_BREAK
case 19:
YY_RULE_SETUP
ST_RET(MONSTER_ID);
	YY_BREAK
case 20:
YY_RULE_SETUP
ST_RET(monster_ID);
	YY_BREAK
case 21:
YY_RULE_SETUP
ST_RET(TRAP_ID);
	YY_BREAK
case 22:
YY_RULE_SETUP
ST_RET(DOOR_ID);
	YY_BREAK
case 23:
YY_RULE_SETUP
ST_RET(ROOMDOOR_ID);
	YY_BREAK
case 24:
YY_RULE_SETUP
ST_RET(DRAWBRIDGE_ID);
	YY_BREAK
case 25:
YY_RULE_SETUP
ST_RET(MAZEWALK_ID);
	YY_BREAK
case 26:
YY_RULE_SETUP
ST_RET(WALLIFY_ID);
	YY_BREAK
case 27:
YY_RULE_SETUP
ST_RET(REGION_ID);
	YY_BREAK
case 28:
YY_RULE_SETUP
ST_RET(ALTAR_ID);
	YY_BREAK
case 29:
YY_RULE_SETUP
ST_RET(LADDER_ID);
	YY_BREAK
case 30:
YY_RULE_SETUP
ST_RET(STAIR_ID);
	YY_BREAK
case 31:
YY_RULE_SETUP
ST_RET(PORTAL_ID);
	YY_BREAK
case 32:
YY_RULE_SETUP
ST_RET(TELEPRT_ID);
	YY_BREAK
case 33:
YY_RULE_SETUP
ST_RET(BRANCH_ID);
	YY_BREAK
case 34:
YY_RULE_SETUP
ST_RET(FOUNTAIN_ID);
	YY_BREAK
case 35:
YY_RULE_SETUP
ST_RET(SINK_ID);
	YY_BREAK
case 36:
YY_RULE_SETUP
ST_RET(POOL_ID);
	YY_BREAK
case 37:
YY_RULE_SETUP
ST_RET(NON_DIGGABLE_ID);
	YY_BREAK
case 38:
YY_RULE_SETUP
ST_RET(NON_PASSWALL_ID);
	YY_BREAK
case 39:
YY_RULE_SETUP
ST_RET(IF_ID);
	YY_BREAK
case 40:
YY_RULE_SETUP
ST_RET(ELSE_ID);
	YY_BREAK
case 41:
YY_RULE_SETUP
ST_RET(EXIT_ID);
	YY_BREAK
case 42:
YY_RULE_SETUP
ST_RET(ROOM_ID);
	YY_BREAK
case 43:
YY_RULE_SETUP
ST_RET(SUBROOM_ID);
	YY_BREAK
case 44:
YY_RULE_SETUP
ST_RET(RAND_CORRIDOR_ID);
	YY_BREAK
case 45:
YY_RULE_SETUP
ST_RET(CORRIDOR_ID);
	YY_BREAK
case 46:
YY_RULE_SETUP
ST_RET(TERRAIN_ID);
	YY_BREAK
case 47:
YY_RULE_SETUP
ST_RET(terrain_ID);
	YY_BREAK
case 48:
YY_RULE_SETUP
ST_RET(REPLACE_TERRAIN_ID);
	YY_BREAK
case 49:
YY_RULE_SETUP
ST_RET(GOLD_ID);
	YY_BREAK
case 50:
YY_RULE_SETUP
ST_RET(GRAVE_ID);
	YY_BREAK
case 51:
YY_RULE_SETUP
ST_RET(ENGRAVING_ID);
	YY_BREAK
case 52:
YY_RULE_SETUP
ST_RET(MINERALIZE_ID);
	YY_BREAK
case 53:
YY_RULE_SETUP
ST_RET(NAME_ID);
	YY_BREAK
case 54:
YY_RULE_SETUP
ST_RET(FOR_ID);
	YY_BREAK
case 55:
YY_RULE_SETUP
ST_RET(TO_ID);
	YY_BREAK
case 56:
YY_RULE_SETUP
ST_RET(LOOP_ID);
	YY_BREAK
case 57:
YY_RULE_SETUP
ST_RET(SWITCH_ID);
	YY_BREAK
case 58:
YY_RULE_SETUP
ST_RET(CASE_ID);
	YY_BREAK
case 59:
YY_RULE_SETUP
ST_RET(BREAK_ID);
	YY_BREAK
case 60:
YY_RULE_SETUP
ST_RET(DEFAULT_ID);
	YY_BREAK
case 61:
YY_RULE_SETUP
ST_RET(FUNCTION_ID);
	YY_BREAK
case 62:
YY_RULE_SETUP
ST_RET(SHUFFLE_ID);
	YY_BREAK
case 63:
YY_RULE_SETUP
ST_RET(MONTYPE_ID);
	YY_BREAK
case 64:
YY_RULE_SETUP
ST_RET(selection_ID);
	YY_BREAK
case 65:
YY_RULE_SETUP
ST_RET(rect_ID);
	YY_BREAK
case 66:
YY_RULE_SETUP
ST_RET(fillrect_ID);
	YY_BREAK
case 67:
YY_RULE_SETUP
ST_RET(line_ID);
	YY_BREAK
case 68:
YY_RULE_SETUP
ST_RET(randline_ID);
	YY_BREAK
case 69:
YY_RULE_SETUP
ST_RET(grow_ID);
	YY_BREAK
case 70:
YY_RULE_SETUP
ST_RET(flood_ID);
	YY_BREAK
case 71:
YY_RULE_SETUP
ST_RET(rndcoord_ID);
	YY_BREAK
case 72:
YY_RULE_SETUP
ST_RET(circle_ID);
	YY_BREAK
case 73:
YY_RULE_SETUP
ST_RET(ellipse_ID);
	YY_BREAK
case 74:
YY_RULE_SETUP
ST_RET(filter_ID);
	YY_BREAK
case 75:
YY_RULE_SETUP
ST_RET(gradient_ID);
	YY_BREAK
case 76:
YY_RULE_SETUP
ST_RET(complement_ID);
	YY_BREAK
case 77:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=SEL_GRADIENT_RADIAL;  return GRADIENT_TYPE; }
	YY_BREAK
case 78:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=SEL_GRADIENT_SQUARE;  return GRADIENT_TYPE; }
	YY_BREAK
case 79:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=DRY;  return HUMIDITY_TYPE; }
	YY_BREAK
case 80:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=WET;  return HUMIDITY_TYPE; }
	YY_BREAK
case 81:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=HOT;  return HUMIDITY_TYPE; }
	YY_BREAK
case 82:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=SOLID;  return HUMIDITY_TYPE; }
	YY_BREAK
case 83:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=ANY_LOC;  return HUMIDITY_TYPE; }
	YY_BREAK
case 84:
YY_RULE_SETUP
ST_RET(LEV);
	YY_BREAK
case 85:
YY_RULE_SETUP
ST_RET(QUANTITY_ID);
	YY_BREAK
case 86:
YY_RULE_SETUP
ST_RET(BURIED_ID);
	YY_BREAK
case 87:
YY_RULE_SETUP
ST_RET(ERODED_ID);
	YY_BREAK
case 88:
YY_RULE_SETUP
ST_RET(ERODEPROOF_ID);
	YY_BREAK
case 89:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=1; return TRAPPED_STATE; }
	YY_BREAK
case 90:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=0; return TRAPPED_STATE; }
	YY_BREAK
case 91:
YY_RULE_SETUP
ST_RET(RECHARGED_ID);
	YY_BREAK
case 92:
YY_RULE_SETUP
ST_RET(INVIS_ID);
	YY_BREAK
case 93:
YY_RULE_SETUP
ST_RET(GREASED_ID);
	YY_BREAK
case 94:
YY_RULE_SETUP
ST_RET(FEMALE_ID);
	YY_BREAK
case 95:
YY_RULE_SETUP
ST_RET(CANCELLED_ID);
	YY_BREAK
case 96:
YY_RULE_SETUP
ST_RET(REVIVED_ID);
	YY_BREAK
case 97:
YY_RULE_SETUP
ST_RET(AVENGE_ID);
	YY_BREAK
case 98:
YY_RULE_SETUP
ST_RET(FLEEING_ID);
	YY_BREAK
case 99:
YY_RULE_SETUP
ST_RET(BLINDED_ID);
	YY_BREAK
case 100:
YY_RULE_SETUP
ST_RET(PARALYZED_ID);
	YY_BREAK
case 101:
YY_RULE_SETUP
ST_RET(STUNNED_ID);
	YY_BREAK
case 102:
YY_RULE_SETUP
ST_RET(CONFUSED_ID);
	YY_BREAK
case 103:
YY_RULE_SETUP
ST_RET(SEENTRAPS_ID);
	YY_BREAK
case 104:
YY_RULE_SETUP
ST_RET(ALL_ID);
	YY_BREAK
case 105:
YY_RULE_SETUP
ST_RETF((yylval.i=1), HORIZ_OR_VERT);
	YY_BREAK
case 106:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=2; return HORIZ_OR_VERT; }
	YY_BREAK
case 107:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=D_ISOPEN; return DOOR_STATE; }
	YY_BREAK
case 108:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=D_CLOSED; return DOOR_STATE; }
	YY_BREAK
case 109:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=D_LOCKED; return DOOR_STATE; }
	YY_BREAK
case 110:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=D_NODOOR; return DOOR_STATE; }
	YY_BREAK
case 111:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=D_BROKEN; return DOOR_STATE; }
	YY_BREAK
case 112:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=D_SECRET; return DOOR_STATE; }
	YY_BREAK
case 113:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=W_NORTH; return DIRECTION; }
	YY_BREAK
case 114:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=W_EAST; return DIRECTION; }
	YY_BREAK
case 115:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=W_SOUTH; return DIRECTION; }
	YY_BREAK
case 116:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=W_WEST; return DIRECTION; }
	YY_BREAK
case 117:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i = -1; return RANDOM_TYPE; }
	YY_BREAK
case 118:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i = -1; return RANDOM_TYPE_BRACKET; }
	YY_BREAK
case 119:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i = -2; return NONE; }
	YY_BREAK
case 120:
YY_RULE_SETUP
ST_RET(A_REGISTER);
	YY_BREAK
case 121:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=1; return LEFT_OR_RIGHT; }
	YY_BREAK
case 122:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=2; return LEFT_OR_RIGHT; }
	YY_BREAK
case 123:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=3; return CENTER; }
	YY_BREAK
case 124:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=4; return LEFT_OR_RIGHT; }
	YY_BREAK
case 125:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=5; return LEFT_OR_RIGHT; }
	YY_BREAK
case 126:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=1; return TOP_OR_BOT; }
	YY_BREAK
case 127:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=5; return TOP_OR_BOT; }
	YY_BREAK
case 128:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=1; return LIGHT_STATE; }
	YY_BREAK
case 129:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=0; return LIGHT_STATE; }
	YY_BREAK
case 130:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=1; return FILLING; }
	YY_BREAK
case 131:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=0; return FILLING; }
	YY_BREAK
case 132:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=0; return IRREGULAR; }
	YY_BREAK
case 133:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=1; return IRREGULAR; }
	YY_BREAK
case 134:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=1; return JOINED; }
	YY_BREAK
case 135:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=0; return JOINED; }
	YY_BREAK
case 136:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=1; return LIMITED; }
	YY_BREAK
case 137:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=0; return LIMITED; }
	YY_BREAK
case 138:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i= AM_NONE; return ALIGNMENT; }
	YY_BREAK
case 139:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i= AM_LAWFUL; return ALIGNMENT; }
	YY_BREAK
case 140:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i= AM_NEUTRAL; return ALIGNMENT; }
	YY_BREAK
case 141:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i= AM_CHAOTIC; return ALIGNMENT; }
	YY_BREAK
case 142:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i= AM_SPLEV_CO; return ALIGNMENT; }
	YY_BREAK
case 143:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i= AM_SPLEV_NONCO; return ALIGNMENT; }
	YY_BREAK
case 144:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=1; return MON_ATTITUDE; }
	YY_BREAK
case 145:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=0; return MON_ATTITUDE; }
	YY_BREAK
case 146:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=1; return MON_ALERTNESS; }
	YY_BREAK
case 147:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=0; return MON_ALERTNESS; }
	YY_BREAK
case 148:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i= M_AP_FURNITURE; return MON_APPEARANCE; }
	YY_BREAK
case 149:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i= M_AP_MONSTER;   return MON_APPEARANCE; }
	YY_BREAK
case 150:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i= M_AP_OBJECT;    return MON_APPEARANCE; }
	YY_BREAK
case 151:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=2; return ALTAR_TYPE; }
	YY_BREAK
case 152:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=1; return ALTAR_TYPE; }
	YY_BREAK
case 153:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=0; return ALTAR_TYPE; }
	YY_BREAK
case 154:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=1; return UP_OR_DOWN; }
	YY_BREAK
case 155:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=0; return UP_OR_DOWN; }
	YY_BREAK
case 156:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=0; return BOOLEAN; }
	YY_BREAK
case 157:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=1; return BOOLEAN; }
	YY_BREAK
case 158:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=DUST; return ENGRAVING_TYPE; }
	YY_BREAK
case 159:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=ENGRAVE; return ENGRAVING_TYPE; }
	YY_BREAK
case 160:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=BURN; return ENGRAVING_TYPE; }
	YY_BREAK
case 161:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=MARK; return ENGRAVING_TYPE; }
	YY_BREAK
case 162:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=ENGR_BLOOD; return ENGRAVING_TYPE; }
	YY_BREAK
case 163:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=1; return CURSE_TYPE; }
	YY_BREAK
case 164:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=2; return CURSE_TYPE; }
	YY_BREAK
case 165:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=3; return CURSE_TYPE; }
	YY_BREAK
case 166:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=NOTELEPORT; return FLAG_TYPE; }
	YY_BREAK
case 167:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=HARDFLOOR; return FLAG_TYPE; }
	YY_BREAK
case 168:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=NOMMAP; return FLAG_TYPE; }
	YY_BREAK
case 169:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=ARBOREAL; return FLAG_TYPE; } /* KMH */
	YY_BREAK
case 170:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=SHORTSIGHTED; return FLAG_TYPE; }
	YY_BREAK
case 171:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=MAZELEVEL; return FLAG_TYPE; }
	YY_BREAK
case 172:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=PREMAPPED; return FLAG_TYPE; }
	YY_BREAK
case 173:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=SHROUD; return FLAG_TYPE; }
	YY_BREAK
case 174:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=GRAVEYARD; return FLAG_TYPE; }
	YY_BREAK
case 175:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=ICEDPOOLS; return FLAG_TYPE; }
	YY_BREAK
case 176:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=SOLIDIFY; return FLAG_TYPE; }
	YY_BREAK
case 177:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=CORRMAZE; return FLAG_TYPE; }
	YY_BREAK
case 178:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=CHECK_INACCESSIBLES; return FLAG_TYPE; }
	YY_BREAK
case 179:
YY_RULE_SETUP
{ char *p = index(yytext, 'd');
		  savetoken(yytext);
		  if (p) {
			*p++ = '\0';
			yylval.dice.num = atoi(yytext);
			yylval.dice.die = atoi(p);
		  } else {
			yylval.dice.num = yylval.dice.die = 1;
		  }
		  return DICE;
		}
	YY_BREAK
case 180:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i = atoi(yytext + 1);
		     if (yylval.i < 0 || yylval.i > 100)
			lc_error("Unexpected percentile '%li%%'", yylval.i);
		     return PERCENT; }
	YY_BREAK
case 181:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=atoi(yytext); return MINUS_INTEGER; }
	YY_BREAK
case 182:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=atoi(yytext); return PLUS_INTEGER; }
	YY_BREAK
case 183:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i = atoi(yytext);
		  if (yylval.i < 0 || yylval.i > 100)
		     lc_error("Unexpected percentile '%li%%'", yylval.i);
		  return SPERCENT; }
	YY_BREAK
case 184:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i=atoi(yytext); return INTEGER; }
	YY_BREAK
case 185:
/* rule 185 can match eol */
YY_RULE_SETUP
{ savetoken(yytext);
		  yytext[yyleng - 1] = '\0'; /* discard the trailing \" */
		  yylval.map = dupstr(yytext + 1); /* skip the first \" */
		  return STRING; }
	YY_BREAK
case 186:
YY_RULE_SETUP
{ savetoken(yytext); return handle_varstring_check(); }
	YY_BREAK
case 187:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i = SPO_JE; return COMPARE_TYPE; }
	YY_BREAK
case 188:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i = SPO_JNE; return COMPARE_TYPE; }
	YY_BREAK
case 189:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i = SPO_JNE; return COMPARE_TYPE; }
	YY_BREAK
case 190:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i = SPO_JLE; return COMPARE_TYPE; }
	YY_BREAK
case 191:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i = SPO_JGE; return COMPARE_TYPE; }
	YY_BREAK
case 192:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i = SPO_JL; return COMPARE_TYPE; }
	YY_BREAK
case 193:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i = SPO_JG; return COMPARE_TYPE; }
	YY_BREAK
case 194:
/* rule 194 can match eol */
YY_RULE_SETUP
{ newline(); }
	YY_BREAK
case 195:
YY_RULE_SETUP
{ advancepos(yytext); }
	YY_BREAK
case 196:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i = yytext[2]; return CHAR; }
	YY_BREAK
case 197:
YY_RULE_SETUP
{ savetoken(yytext); yylval.i = yytext[1]; return CHAR; }
	YY_BREAK
case 198:
YY_RULE_SETUP
ST_RET(UNKNOWN_TYPE);
	YY_BREAK
case 199:
YY_RULE_SETUP
{ savetoken(yytext); return yytext[0]; }
	YY_BREAK
case 200:
YY_RULE_SETUP
ECHO;
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(MAPC):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer ()
{
        char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
    char *source = (yytext_ptr);
    yy_size_t number_to_move, i;
    int ret_val;

    if ((yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1])
        YY_FATAL_ERROR("fatal flex scanner internal error--end of buffer missed");

    if (YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0) {
        /* Don't try to fill the buffer, so this is an EOF. */
        if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 ) {
            /* We matched a single character, the EOB, so
             * treat this as a final EOF.
             */
            return EOB_ACT_END_OF_FILE;
        } else {
            /* We matched some text prior to the EOB, first
             * process it.
             */
            return EOB_ACT_LAST_MATCH;
        }
    }

    /* Try to read more data. */

    /* First move last chars to start of buffer. */
    number_to_move = (yy_size_t) ((yy_c_buf_p) - (yytext_ptr)) - 1;

    for (i = 0; i < number_to_move; ++i)
        *(dest++) = *(source++);

    if (YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING) {
        /* don't do the read, it's not guaranteed to return an EOF,
         * just force an EOF
         */
        YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;
    } else {
        yy_size_t num_to_read;
        /* just a shorter name for the current buffer */
        YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

            /* [pr] This could probably be (b->yy_buf_size < number_to_move)
             * since the allocated size is actually b->yy_buf_size + 2.
             * The old code calculated num_to_read above (with same formula
             * as is used below), then used (num_to_read <= 0) here, which
             * got broken when num_to_read was changed to an unsigned type. */
        while (b->yy_buf_size <= number_to_move + 1) {
            /* Not enough room in the buffer - grow it. */

            int yy_c_buf_p_offset = (int) ((yy_c_buf_p) - b->yy_ch_buf);

            if ( b->yy_is_our_buffer ) {
                b->yy_buf_size += b->yy_buf_size / 4;
                b->yy_ch_buf = (char *)
                         /* Include room in for 2 EOB chars. */
                         yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2 );
            } else
                /* Can't grow it, we don't own it. */
                b->yy_ch_buf = 0;

            if (! b->yy_ch_buf)
                YY_FATAL_ERROR("fatal error - scanner input buffer overflow");

            (yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

        }

        num_to_read = b->yy_buf_size - number_to_move - 1;
        if ( num_to_read > YY_READ_BUF_SIZE )
            num_to_read = YY_READ_BUF_SIZE;

        /* Read in more data. */
        YY_INPUT((&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
                (yy_n_chars), num_to_read);
        YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
    }

    if ((yy_n_chars) == 0) {
        if (number_to_move == YY_MORE_ADJ) {
            ret_val = EOB_ACT_END_OF_FILE;
            yyrestart(yyin  );
        } else {
            ret_val = EOB_ACT_LAST_MATCH;
            YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_EOF_PENDING;
        }
    } else
        ret_val = EOB_ACT_CONTINUE_SCAN;

    if ((yy_size_t) ((yy_n_chars) + number_to_move)
                    > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
        /* Extend the array by 50%, plus the number we really need. */
        yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
        YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *)
                yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
        if (! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf)
            YY_FATAL_ERROR("out of dynamic memory in yy_get_next_buffer()");
    }

    (yy_n_chars) += number_to_move;
    YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
    YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

    (yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

    return ret_val;
}

/* yy_get_previous_state - get the state just before EOB char was reached */

static yy_state_type yy_get_previous_state ()
{
    yy_state_type yy_current_state;
    char *yy_cp;

	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

    for (yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp) {

		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 1057 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
    }

    return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */

static yy_state_type yy_try_NUL_trans (yy_current_state )
        yy_state_type yy_current_state;
{
	int yy_is_jam;
    	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 1057 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 1056);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

void yyunput (c,yy_bp )
        int c;
        char * yy_bp;
{
	char *yy_cp;

    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		yy_size_t number_to_move = (yy_n_chars) + 2;
		char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#endif

#ifndef YY_NO_INPUT
static int input ()
{
	int c;

	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			yy_size_t offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					return input();
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(uchar *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 *
 * @note This function does not reset the start condition to @c INITIAL .
 */

void yyrestart (input_file )
        FILE * input_file;
{

	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 *
 */
void yy_switch_to_buffer (new_buffer )
        YY_BUFFER_STATE  new_buffer;
{

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
	 */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state ()
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 *
 * @return the allocated buffer state.
 */
YY_BUFFER_STATE yy_create_buffer (file,size )
        FILE * file;
        int  size;
{
	YY_BUFFER_STATE b;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );
        if (!size)
            size = YY_BUF_SIZE;

	b->yy_buf_size = (yy_size_t)size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 *
 */
void yy_delete_buffer (b )
        YY_BUFFER_STATE  b;
{

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf  );

	yyfree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
static void yy_init_buffer (b,file )
        YY_BUFFER_STATE  b;
        FILE * file;
{
	int oerrno = errno;

	yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;

	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 *
 */
void yy_flush_buffer (b )
        YY_BUFFER_STATE  b;
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *
 */
void yypush_buffer_state (new_buffer )
        YY_BUFFER_STATE new_buffer;
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *
 */
void yypop_buffer_state ()
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack ()
{
    yy_size_t num_to_alloc;

    if (!(yy_buffer_stack)) {
        /* First allocation is just for 2 elements, since we don't know if this
         * scanner will even need a stack. We use 2 instead of 1 to avoid an
         * immediate realloc on the next call.
         */
#if 1   /* [PR] avoid C++-style comment; older C compilers choke on it */
        num_to_alloc = 2; /* also changed to match the comment... */
#else
        num_to_alloc = 1; // After all that talk, this was set to 1 anyways...
#endif
        (yy_buffer_stack) = (struct yy_buffer_state**)
                yyalloc(num_to_alloc * sizeof(struct yy_buffer_state*) );
        if (!(yy_buffer_stack))
            YY_FATAL_ERROR("out of dynamic memory in yyensure_buffer_stack()");

        (void) memset((yy_buffer_stack), 0,
                      num_to_alloc * sizeof(struct yy_buffer_state*));

        (yy_buffer_stack_max) = num_to_alloc;
        (yy_buffer_stack_top) = 0;
        return;
    }

    if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1) {
        /* Increase the buffer to prepare for a possible push. */
        yy_size_t grow_size = 8 /* arbitrary grow size */;

        num_to_alloc = (yy_buffer_stack_max) + grow_size;
        (yy_buffer_stack) = (struct yy_buffer_state**)
                yyrealloc((yy_buffer_stack),num_to_alloc * sizeof(struct yy_buffer_state*) );
        if (!(yy_buffer_stack))
            YY_FATAL_ERROR("out of dynamic memory in yyensure_buffer_stack()");

        /* zero only the new slots.*/
        (void) memset((yy_buffer_stack) + (yy_buffer_stack_max), 0,
                      grow_size * sizeof(struct yy_buffer_state*));
        (yy_buffer_stack_max) = num_to_alloc;
    }
}

/** Setup the input buffer state to scan directly from a user-specified
 * character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 *
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer (base,size )
        char * base;
        yy_size_t  size;
{
	YY_BUFFER_STATE b;

	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex()
 * will scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 *
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yystr )
        yyconst char * yystr;
{

	return yy_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to
 * yylex() will scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a
 * bytes.
 *
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes (yybytes,_yybytes_len )
        yyconst char * yybytes;
        yy_size_t  _yybytes_len;
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	yy_size_t i;

	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (msg )
        yyconst char* msg;
{
			(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
    do { \
	/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg); \
	yytext[yyleng] = (yy_hold_char); \
	(yy_c_buf_p) = yytext + yyless_macro_arg; \
	(yy_hold_char) = *(yy_c_buf_p); \
	*(yy_c_buf_p) = '\0'; \
	yyleng = yyless_macro_arg; \
    } while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 *
 */
int yyget_lineno ()
{

    return yylineno;
}

/** Get the input stream.
 *
 */
FILE *yyget_in ()
{
        return yyin;
}

/** Get the output stream.
 *
 */
FILE *yyget_out ()
{
        return yyout;
}

/** Get the length of the current token.
 *
 */
yy_size_t yyget_leng ()
{
        return yyleng;
}

/** Get the current token.
 *
 */

char *yyget_text ()
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 *
 */
void yyset_lineno (_line_number )
        int  _line_number;
{

    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 *
 * @see yy_switch_to_buffer
 */
void yyset_in (_in_str )
        FILE *  _in_str;
{
        yyin = _in_str ;
}

void yyset_out (_out_str )
        FILE *  _out_str;
{
        yyout = _out_str ;
}

int yyget_debug ()
{
        return yy_flex_debug;
}

void yyset_debug (_bdebug )
        int  _bdebug;
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals ()
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy ()
{

    /* Pop the buffer stack, destroying each element. */
    while (YY_CURRENT_BUFFER) {
        yy_delete_buffer(YY_CURRENT_BUFFER  );
        YY_CURRENT_BUFFER_LVALUE = NULL;
        yypop_buffer_state();
    }
    /* Destroy the stack itself. */
    yyfree((yy_buffer_stack) );
    (yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner
     * so the next time yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (s1,s2,n )
        char* s1;
        yyconst char * s2;
        int n;
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (s )
        yyconst char * s;
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (size )
        yy_size_t  size;
{
		
	return (void *) malloc( size );
}

void *yyrealloc (ptr,size )
        void * ptr;
        yy_size_t  size;
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (ptr )
        void * ptr;
{
		
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#ifdef	AMIGA
long *
alloc(n)
    unsigned n;
{
    return (long *) malloc(n);
}
#endif

/* routine to switch to another input file; needed for flex */
void
init_yyin( input_f )
FILE *input_f;
{
#if defined(FLEX_SCANNER) || defined(FLEXHACK_SCANNER)
    if (yyin)
        yyrestart(input_f);
    else
#endif
        yyin = input_f;

    if (!orig_yyin)
        orig_yyin = yyin;
}
/* analogous routine (for completeness) */
void
init_yyout( output_f )
FILE *output_f;
{
    yyout = output_f;
}

long
handle_varstring_check()
{
    struct lc_vardefs *vd;

    yylval.map = dupstr(yytext);
    if ((vd = vardef_defined(vardefs, yytext, 1)) != 0) {
        long l = vd->var_type;
        int a = ((l & SPOVAR_ARRAY) == SPOVAR_ARRAY);

        l &= ~SPOVAR_ARRAY;
        if (l == SPOVAR_INT)
	    return (a ? VARSTRING_INT_ARRAY : VARSTRING_INT);
        if (l == SPOVAR_STRING)
	    return (a ? VARSTRING_STRING_ARRAY : VARSTRING_STRING);
        if (l == SPOVAR_VARIABLE)
	    return (a ? VARSTRING_VAR_ARRAY : VARSTRING_VAR);
        if (l == SPOVAR_COORD)
	    return (a ? VARSTRING_COORD_ARRAY : VARSTRING_COORD);
        if (l == SPOVAR_REGION)
	    return (a ? VARSTRING_REGION_ARRAY : VARSTRING_REGION);
        if (l == SPOVAR_MAPCHAR)
	    return (a ? VARSTRING_MAPCHAR_ARRAY : VARSTRING_MAPCHAR);
        if (l == SPOVAR_MONST)
	    return (a ? VARSTRING_MONST_ARRAY : VARSTRING_MONST);
        if (l == SPOVAR_OBJ)
	    return (a ? VARSTRING_OBJ_ARRAY : VARSTRING_OBJ);
        if (l == SPOVAR_SEL)
	    return (a ? VARSTRING_SEL_ARRAY : VARSTRING_SEL);
    }
    return VARSTRING;
}

void
newline()
{
    nh_line_number++;
    token_start_pos = 0;
    (void) memset((genericptr_t) curr_token, 0, 512);
}

void
savetoken(s)
char *s;
{
    Sprintf(curr_token, "%s", s);
    advancepos(s);
}

void
advancepos(s)
char *s;
{
    token_start_pos += strlen(s);
}

/*lev_comp.l*/

